-- /packages/sencha-member-portlet/sencha-member-portlet-create.sql
--
-- Copyright (c) 2014 Project Open Business Solutions S.L.
--
-- All rights reserved. Please check
-- http://www.project-open.com/license/ for details.
--
-- @author klaus.hofeditz@project-open.com

---------------------------------------------------------
-- Components
---------------------------------------------------------

-- Create component "Copy Project Assignments"
create or replace function inline_1 ()
returns integer as $BODY$
declare
        v_plugin_id             integer;
	v_project_manager	integer;
	v_senior_manager	integer;
begin
        SELECT  im_component_plugin__new (
		        null,						-- plugin_id
        		'im_component_plugin',				-- object_type
			now(),						-- creation_date
        		null,						-- creation_user
        		null,						-- creation_ip
        		null,						-- context_id
        		'Copy Project Assignments',			-- plugin_name
        		'sencha-member-portlet',			-- package_name
        		'right',					-- location
        		'/intranet/users/view',				-- page_url
        		null,                          	       		-- view_name
        		5,						-- sort_order
        		'im_project_copy_user_assignments $user_id $return_url' 	-- component_tcl
		) into v_plugin_id;

		select group_id into v_project_manager from groups where group_name = 'Project Managers';
		PERFORM im_grant_permission(v_plugin_id, v_project_manager, 'read');

		select group_id into v_senior_manager from groups where group_name = 'Senior Managers';
		PERFORM im_grant_permission(v_plugin_id, v_senior_manager, 'read');
		
        return 0;

end;$BODY$ language 'plpgsql';

select inline_1 ();
drop function inline_1();


-- Create component "Bulk Assignement"
create or replace function inline_1 ()
returns integer as $BODY$
declare
        v_plugin_id             integer;
        v_project_manager       integer;
	v_senior_manager	integer;
begin

        SELECT  im_component_plugin__new (
                null,                           -- plugin_id
                'im_component_plugin',		-- object_type
                 now(),                         -- creation_date
                 null,                          -- creation_user
                 null,                          -- creation_ip
                 null,                          -- context_id
                 'Bulk Assignments (Beta)',	-- plugin_name
                 'sencha-member-portlet',      	-- package_name
                 'left',                        -- location
        	 '/intranet/users/view',       	-- page_url
                 null,                          -- view_name
                 5,                             -- sort_order
                 'im_project_bulk_assignment_component $user_id' -- component_tcl
        ) into v_plugin_id;


        select group_id into v_project_manager from groups where group_name = 'Project Managers';
        PERFORM im_grant_permission(v_plugin_id, v_project_manager, 'read');

        select group_id into v_senior_manager from groups where group_name = 'Senior Managers';
        PERFORM im_grant_permission(v_plugin_id, v_senior_manager, 'read');

        return 0;

end;$BODY$ language 'plpgsql';
select inline_1 ();
drop function inline_1();


-- Create report for xhtml request used in portlet    
create or replace function inline_1 ()
returns integer as $BODY$
declare
        v_report_id             integer;
        v_menu_id  		integer;
	v_employees		integer;
	v_sql			varchar;
begin
                SELECT im_menu__new (
                        null,						-- p_menu_id
                        'im_menu',					-- object_type
                        now(),						-- creation_date
                        null,						-- creation_user
                        null,						-- creation_ip
                        null,						-- context_id

                        'sencha-member-portlet',			-- package_name
                        'xhtml_sencha_member_portlet_find_employees',   -- label
                        'Please do not change or remove', 		-- name
                        '/intranet/users/view',	 			-- url
                        100000,                 			-- sort_order
                        null,               	   			-- parent_menu_id
                        null                	   			-- p_visible_tcl
                ) into v_menu_id;

				
        v_sql := 'select u.user_id as employee_id, im_name_from_user_id(u.user_id, 3) as employee_name from cc_users u LEFT JOIN im_employees e ON (u.user_id = e.employee_id), ';
        v_sql := v_sql || '(select member_id from group_distinct_member_map m where group_id = ''463'') m ';
        v_sql := v_sql || 'where u.user_id = m.member_id and u.member_state = ''approved'' and (lower(u.first_names) like lower(''%%%search_str%%%'') OR lower(u.last_name) like lower(''%%%search_str%%%''))';

        SELECT im_report__new(
                        null,
                        'im_report',
                        now(),
                        624,
                        '0.0.0.0',
                        null,

                        'xhtml_sencha_member_portlet_find_employees',
                        'xhtml_sencha_member_portlet_find_employees',
                        15110,
                        15000,
                        v_menu_id,
						v_sql						
        ) into v_report_id;

        -- Set permissions
        select group_id into v_employees from groups where group_name = 'Employees';
        PERFORM acs_permission__grant_permission(v_menu_id, v_employees, 'read');
        return 0;

end;$BODY$ language 'plpgsql';
select inline_1 ();
drop function inline_1();


CREATE OR REPLACE FUNCTION im_rels_transfer_user_projects_and_tasks(INTEGER, INTEGER) RETURNS INTEGER AS $body$
       -- transfers all project/sub-project relationships from one user to another 
       -- transfers object_role, excludes percentage
        DECLARE
              p_source_user_id        alias for $1;
              p_target_user_id        alias for $2;
              v_count                 INTEGER;
              r                       record;
        BEGIN
              FOR r IN 
                     select 
                            rels.object_id_one,
                            biz.object_role_id
                     from 
                            acs_rels rels, 
                            im_biz_object_members biz,
                            acs_objects obj
                     where 
                            rels.object_id_two = p_source_user_id and 
                            obj.object_id = rels.object_id_one and 
                            -- obj.object_type in ('im_project','im_timesheet_task') and 
                            obj.object_type in ('im_project') and 
                            rels.rel_type='im_biz_object_member' and 
                            rels.rel_id = biz.rel_id       
              LOOP
                            perform im_biz_object_member__new(null,'im_biz_object_member',r.object_id_one,p_target_user_id,r.object_role_id,null,null,'');
              END LOOP;
              return 0;
         END;
$body$ LANGUAGE 'plpgsql';
